@@ -18,11 +18,12 @@ import fondos
 import habilidades
 import eventos
 import sonidos
-#import musica
+import musica
 import colores
 import atajos
 import escenas
 import interfaz
+import log
 
 try:
     import aplicacion
@@ -46,7 +47,7 @@ para iniciar y ejecutar la biblioteca.
 if utils.esta_en_sesion_interactiva():
     utils.cargar_autocompletado()
 
-def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='qt', 
+def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='qtgl',
             rendimiento=60, modo='detectar', gravedad=(0, -90), pantalla_completa=False):
     """
     Inicia la ventana principal del juego con algunos detalles de funcionamiento.
@@ -69,7 +70,7 @@ def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='qt',
     :pantalla_completa: si debe usar pantalla completa o no.
 
     """
-    
+
     global mundo
 
     motor = _crear_motor(usar_motor)
@@ -78,10 +79,24 @@ def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='qt',
         mundo = Mundo(motor, ancho, alto, titulo, rendimiento, gravedad, pantalla_completa)
         escenas.Normal(colores.grisclaro)
 
+def iniciar_con_asistente(ancho=640, alto=480, titulo='Pilas',
+            rendimiento=60, modo='detectar', gravedad=(0, -90), imagen="asistente.png"):
+    """Identica a la función iniciar, solo que permite al usuario seleccionar
+    el motor multimedia y el modo de video a utilizar.
+
+    Esta función es útil cuando se quiere distribuir un juego y no se conoce
+    exáctamente el equipo del usuario.
+    """
+
+    import asistente
+
+    usar_motor, pantalla_completa = asistente.ejecutar(imagen, titulo)
+    iniciar(ancho, alto, titulo, usar_motor, rendimiento, modo, gravedad, pantalla_completa)
+
 
 def ejecutar(ignorar_errores=False):
     """Pone en funcionamiento las actualizaciones y dibujado.
-    
+
     Esta función es necesaria cuando se crea un juego
     en modo ``no-interactivo``."""
     mundo.ejecutar_bucle_principal(ignorar_errores)
@@ -101,7 +116,7 @@ def version():
 
 def _crear_motor(usar_motor):
     """Genera instancia del motor multimedia en base a un nombre.
-    
+
     Esta es una función interna y no debe ser ejecutada
     excepto por el mismo motor pilas."""
 
@@ -117,32 +132,17 @@ def _crear_motor(usar_motor):
 
 def reiniciar():
     """Elimina todos los actores y vuelve al estado inicial."""
-    actores.utils.eliminar_a_todos()
     mundo.reiniciar()
 
-anterior_texto = None
-
 def avisar(mensaje):
     """Emite un mensaje en la ventana principal.
 
-    Este mensaje aparecerá en la parte inferior de la pantalla, por
-    ejemplo:
+    Este mensaje aparecerá en la parte inferior de la pantalla durante
+    5 segundo, por ejemplo:
 
         >>> pilas.avisar("Use la tecla <esc> para terminar el programa")
     """
-    global anterior_texto
-    izquierda, derecha, arriba, abajo = utils.obtener_bordes()
-
-    if anterior_texto:
-        anterior_texto.eliminar()
-
-    texto = actores.Texto(mensaje)
-    texto.magnitud = 17
-    texto.centro = ("centro", "centro")
-    texto.izquierda = izquierda + 10
-    texto.color = colores.blanco
-    texto.abajo = abajo + 10
-    anterior_texto = texto
+    actores.TextoInferior(mensaje, autoeliminar=True)
 
 def abrir_cargador():
     """Abre un cargador de ejemplos con varios códigos de prueba.
@@ -167,7 +167,7 @@ def abrir_cargador():
 
 def abrir_interprete():
     """Abre un intérprete interactivo de python con una ventana.
-    
+
     Esta función se ejecuta cuando un usuario escribe::
 
         pilas -i
