@@ -65,6 +65,8 @@ class Actor(object, Estudiante):
         self._actor = pilas.mundo.motor.obtener_actor(imagen, x=x, y=y)
         self.centro = ('centro', 'centro')
 
+        self.id = ""
+
         self.x = x
         self.y = y
         self.transparencia = 0
@@ -85,11 +87,11 @@ class Actor(object, Estudiante):
         if type(y) == str:
             if y not in ARRIBA + CENTRO + ABAJO:
                 raise Exception("No puedes definir '%s' como eje vertical." %(y))
-            y = self._interpretar_y_convertir_posicion(y, self.obtener_alto())            
+            y = self._interpretar_y_convertir_posicion(y, self.obtener_alto())
 
         self._centro = (x, y)
         self._actor.definir_centro(x, y)
-    
+
     def _interpretar_y_convertir_posicion(self, posicion, maximo_valor):
         if posicion in IZQUIERDA + ARRIBA:
             return 0
@@ -102,7 +104,7 @@ class Actor(object, Estudiante):
 
     def obtener_centro(self):
         return self._centro
-    
+
     centro = property(obtener_centro, definir_centro, doc="""
         Cambia la posición del punto (x, y) dentro de actor.
 
@@ -252,7 +254,7 @@ class Actor(object, Estudiante):
         """Elimina el actor de la lista de actores que se imprimen en pantalla."""
         self.destruir()
         self._eliminar_anexados()
-    
+
     def destruir(self):
         """Elimina a un actor pero de manera inmediata."""
         pilas.actores.utils.eliminar_un_actor(self)
@@ -260,13 +262,14 @@ class Actor(object, Estudiante):
         self.eliminar_comportamientos()
 
     def actualizar(self):
-        """Actualiza el estado del actor. 
-        
+        """Actualiza el estado del actor.
+
         Este metodo se llama una vez por frame, y generalmente se suele
         usar para implementar el comportamiento del actor.
 
         Si estás haciendo una subclase de Actor, es aconsejable que re-definas
         este método."""
+        pass
 
     def pre_actualizar(self):
         """Actualiza comportamiento y habilidades antes de la actualización."""
@@ -294,7 +297,7 @@ class Actor(object, Estudiante):
         self.x = x + (self.centro[0] * self.escala)
 
     izquierda = property(get_izquierda, set_izquierda)
-    
+
     def get_derecha(self):
         return self.izquierda + self.obtener_ancho()
 
@@ -310,7 +313,7 @@ class Actor(object, Estudiante):
     @pilas.utils.interpolable
     def set_abajo(self, y):
         self.set_arriba(y + self.alto)
-        
+
     abajo = property(get_abajo, set_abajo)
 
     def get_arriba(self):
@@ -391,6 +394,7 @@ class Actor(object, Estudiante):
     def decir(self, mensaje, autoeliminar=True):
         """Emite un mensaje usando un globo similar al de los commics"""
         nuevo_actor = pilas.actores.Globo(mensaje, self.x, self.y, autoeliminar=autoeliminar)
+        nuevo_actor.aprender(pilas.habilidades.Imitar, self, False)
         nuevo_actor.z = self.z - 1
         self.anexar(nuevo_actor)
         pilas.atajos.leer(mensaje)
@@ -403,8 +407,9 @@ class Actor(object, Estudiante):
             x.eliminar()
 
     def esta_fuera_de_la_pantalla(self):
+        "Indica si el actor está fuera del area visible de la pantalla."
         izquierda, derecha, arriba, abajo = pilas.mundo.camara.obtener_area_visible()
         return self.derecha < izquierda or self.izquierda > derecha or self.abajo > arriba or self.arriba < abajo
 
-
-
+    def es_fondo(self):
+        return False
