@@ -53,7 +53,9 @@ class Depurador(object):
                 m.termina_dibujado(motor, self.lienzo)
     
     def cuando_pulsa_tecla(self, evento):
-        if evento.codigo == 'F7':
+        if evento.codigo == 'F6':
+            pilas.eventos.imprimir_todos()
+        elif evento.codigo == 'F7':
             self._alternar_modo(ModoInformacionDeSistema)
         elif evento.codigo == 'F8':
             self._alternar_modo(ModoPuntosDeControl)
@@ -82,7 +84,7 @@ class Depurador(object):
             self._activar_modo(clase_del_modo)
     
     def _activar_modo(self, clase_del_modo):
-        pilas.eventos.inicia_modo_depuracion.send('depurador')
+        pilas.eventos.inicia_modo_depuracion.emitir()
         instancia_del_modo = clase_del_modo(self)
         self.modos.append(instancia_del_modo)
         # Ordena todos los registros por numero de tecla.
@@ -95,7 +97,7 @@ class Depurador(object):
         instancia_a_eliminar[0].sale_del_modo()
         
         if not self.modos:
-            pilas.eventos.sale_modo_depuracion.send('depurador')
+            pilas.eventos.sale_modo_depuracion.emitir()
 
     def _mostrar_nombres_de_modos(self, motor):
         dy = 0
@@ -152,20 +154,20 @@ class ModoPuntosDeControl(ModoDepurador):
     tecla = "F8"
     
     def dibuja_al_actor(self, motor, lienzo, actor):
-        lienzo.cruz(motor, actor.x, actor.y, color=pilas.colores.rojo, grosor=ModoDepurador.grosor_de_lineas)
+        lienzo.cruz(motor, actor.x - pilas.mundo.camara.x, actor.y - pilas.mundo.camara.y, color=pilas.colores.rojo, grosor=ModoDepurador.grosor_de_lineas)
         
 class ModoRadiosDeColision(ModoDepurador):
     tecla = "F9"
     
     def dibuja_al_actor(self, motor, lienzo, actor):
-        lienzo.circulo(motor, actor.x, actor.y, actor.radio_de_colision, color=pilas.colores.verde, grosor=ModoDepurador.grosor_de_lineas)
+        lienzo.circulo(motor, actor.x - pilas.mundo.camara.x, actor.y - pilas.mundo.camara.y, actor.radio_de_colision, color=pilas.colores.verde, grosor=ModoDepurador.grosor_de_lineas)
  
 class ModoArea(ModoDepurador):
     tecla = "F10"
     
     def dibuja_al_actor(self, motor, lienzo, actor):
         dx, dy = actor.centro
-        lienzo.rectangulo(motor, actor.x - dx, actor.y + dy, actor.ancho, actor.alto, color=pilas.colores.azul, grosor=ModoDepurador.grosor_de_lineas)
+        lienzo.rectangulo(motor, actor.x - dx - pilas.mundo.camara.x, actor.y + dy - pilas.mundo.camara.y, actor.ancho, actor.alto, color=pilas.colores.azul, grosor=ModoDepurador.grosor_de_lineas)
 
 class ModoPosicion(ModoDepurador):
     tecla = "F12"
@@ -177,7 +179,7 @@ class ModoPosicion(ModoDepurador):
     def dibuja_al_actor(self, motor, lienzo, actor):
         if not isinstance(actor, pilas.fondos.Fondo):
             texto = "(%d, %d)" %(actor.x, actor.y)
-            lienzo.texto(motor, texto, actor.derecha, actor.abajo, color=pilas.colores.violeta)
+            lienzo.texto(motor, texto, actor.derecha - pilas.mundo.camara.x, actor.abajo - pilas.mundo.camara.y, color=pilas.colores.violeta)
 
     def sale_del_modo(self):
         self.eje.eliminar()
@@ -200,6 +202,7 @@ class ModoInformacionDeSistema(ModoDepurador):
             "Sistema: " + sys.platform,
             "Version de pilas: " + pilasversion.VERSION,
             "Version de python: " + sys.subversion[0] + " " + sys.subversion[1],
+            "Version de Box2D: " + pilas.fisica.obtener_version(),
             ]
     
     def termina_dibujado(self, motor, lienzo):
