@@ -11,14 +11,22 @@ from pilas import colores
 
 try:
     import Box2D as box2d
+    contact_listener = box2d.b2ContactListener
 except ImportError:
+    class Tmp:
+        pass
+    contact_listener = Tmp
     print "No esta disponible box2d, se deshabilitara la fisica."
 
 import math
 
+def obtener_version():
+    """Obtiene la versión de la biblioteca Box2D"""
+    return box2d.__version__
+
 class Fisica(object):
     """Representa un simulador de mundo fisico, usando la biblioteca box2d."""
-    
+
     def __init__(self, area, gravedad=(0, -90)):
         self.area = area
         try:
@@ -28,6 +36,8 @@ class Fisica(object):
             self.gravedad = box2d.b2Vec2(gravedad[0], gravedad[1])
             try:
                 self.mundo = box2d.b2World(self.escenario, self.gravedad, True)
+                self.objetosContactListener = ObjetosContactListener()
+                self.mundo.SetContactListener(self.objetosContactListener)
             except ValueError:
                 print "Solo esta disponible el motor de fisica para box2d 2.0.2b1"
                 raise AttributeError("...")
@@ -47,7 +57,9 @@ class Fisica(object):
         self.crear_paredes(self.area)
 
     def reiniciar(self):
-        for x in self.mundo.bodyList:
+        lista = list(self.mundo.bodyList)
+
+        for x in lista:
             self.mundo.DestroyBody(x)
 
         self.crear_bordes_del_escenario()
@@ -55,9 +67,9 @@ class Fisica(object):
     def capturar_figura_con_el_mouse(self, figura):
         if self.constante_mouse:
             self.cuando_suelta_el_mouse()
-        
+
         self.constante_mouse = ConstanteDeMovimiento(figura)
-    
+
     def cuando_mueve_el_mouse(self, x, y):
         if self.constante_mouse:
             self.constante_mouse.mover(x, y)
@@ -66,7 +78,7 @@ class Fisica(object):
         if self.constante_mouse:
             self.constante_mouse.eliminar()
             self.constante_mouse = None
-        
+
     def actualizar(self, velocidad=1.0):
         if self.mundo:
             self.mundo.Step(velocidad / 20.0, 10, 8)
@@ -86,41 +98,41 @@ class Fisica(object):
         "Dibuja todas las figuras en una pizarra. Indicado para depuracion."
         cuerpos = self.mundo.bodyList
         cantidad_de_figuras = 0
-        
+
         for cuerpo in cuerpos:
             xform = cuerpo.GetXForm()
-            
+
             for figura in cuerpo.shapeList:
                 cantidad_de_figuras += 1
                 tipo_de_figura = figura.GetType()
-                
+
                 if tipo_de_figura == box2d.e_polygonShape:
                     vertices = []
-                    
+
                     for v in figura.vertices:
                         pt = box2d.b2Mul(xform, v)
-                        vertices.append((pt.x, pt.y))
-                        
+                        vertices.append((pt.x - pilas.mundo.camara.x, pt.y - pilas.mundo.camara.y))
+
                     lienzo.poligono(motor, vertices, color=colores.rojo, grosor=grosor, cerrado=True)
-                    
+
                 elif tipo_de_figura == box2d.e_circleShape:
-                    lienzo.circulo(motor, cuerpo.position.x, cuerpo.position.y, figura.radius, colores.rojo, grosor=grosor)
+                    lienzo.circulo(motor, cuerpo.position.x - pilas.mundo.camara.x, cuerpo.position.y - pilas.mundo.camara.y, figura.radius, colores.rojo, grosor=grosor)
                 else:
                     print "no puedo identificar el tipo de figura."
-        
+
     def crear_cuerpo(self, definicion_de_cuerpo):
         return self.mundo.CreateBody(definicion_de_cuerpo)
-    
+
     def crear_suelo(self, (ancho, alto), restitucion=0):
         self.suelo = Rectangulo(0, -alto/2, ancho, 2, dinamica=False, fisica=self, restitucion=restitucion)
 
     def crear_techo(self, (ancho, alto), restitucion=0):
         self.techo = Rectangulo(0, alto/2, ancho, 2, dinamica=False, fisica=self, restitucion=restitucion)
-        
+
     def crear_paredes(self, (ancho, alto), restitucion=0):
         self.pared_izquierda = Rectangulo(-ancho/2, 0, 2, alto, dinamica=False, fisica=self, restitucion=restitucion)
         self.pared_derecha = Rectangulo(ancho/2, 0, 2, alto, dinamica=False, fisica=self, restitucion=restitucion)
-        
+
     def eliminar_suelo(self):
         if self.suelo:
             self.suelo.eliminar()
@@ -130,39 +142,39 @@ class Fisica(object):
         if self.techo:
             self.techo.eliminar()
             self.techo = None
-            
+
     def eliminar_paredes(self):
         if self.pared_izquierda:
             self.pared_derecha.eliminar()
             self.pared_izquierda.eliminar()
             self.pared_derecha = None
             self.pared_izquierda = None
-    
+
     def eliminar_figura(self, figura):
         self.figuras_a_eliminar.append(figura)
-        
+
     def obtener_distancia_al_suelo(self, x, y, dy):
-        """Obtiene la distancia hacia abajo desde el punto (x,y). 
-        
+        """Obtiene la distancia hacia abajo desde el punto (x,y).
+
         El valor de 'dy' tiene que ser positivo.
-        
+
         Si la funcion no encuentra obstaculos retornara
         dy, pero en paso contrario retornara un valor menor
         a dy.
         """
-        
+
         if dy < 0:
             raise Exception("El valor de 'dy' debe ser positivo, ahora vale '%f'." %(dy))
 
         delta = 0
-        
+
         while delta < dy:
-            
+
             if self.obtener_cuerpos_en(x, y-delta):
                 return delta
-            
+
             delta += 1
-            
+
         return delta
 
     def obtener_cuerpos_en(self, x, y):
@@ -177,27 +189,30 @@ class Fisica(object):
 
         if cuantos == 0:
             return []
-        
+
         lista_de_cuerpos = []
-        
+
         for s in cuerpos:
             cuerpo = s.GetBody()
-                    
+
             if s.TestPoint(cuerpo.GetXForm(), (x, y)):
                 lista_de_cuerpos.append(cuerpo)
 
         return lista_de_cuerpos
-    
+
     def definir_gravedad(self, x, y):
         pilas.fisica.definir_gravedad(x, y)
 
 class Figura(object):
     """Representa un figura que simula un cuerpo fisico.
-    
+
     Esta figura es abstracta, no está pensada para crear
     objetos a partir de ella. Se usa como base para el resto
     de las figuras cómo el Circulo o el Rectangulo simplemente."""
 
+    def __init__(self):
+        self.id = pilas.utils.obtener_uuid()
+
     def obtener_x(self):
         return self._cuerpo.position.x
 
@@ -207,6 +222,10 @@ class Figura(object):
     def obtener_y(self):
         return self._cuerpo.position.y
 
+    def definir_posicion(self, x, y):
+        self.definir_x(x)
+        self.definir_y(y)
+
     def definir_y(self, y):
         self._cuerpo.SetXForm((self.x, y), self._cuerpo.GetAngle())
 
@@ -215,10 +234,10 @@ class Figura(object):
 
     def definir_rotacion(self, angulo):
         self._cuerpo.SetXForm((self.x, self.y), math.radians(-angulo))
-        
+
     def impulsar(self, dx, dy):
         self._cuerpo.ApplyImpulse((dx, dy), self._cuerpo.GetWorldCenter())
-        
+
     def obtener_velocidad_lineal(self):
         velocidad = self._cuerpo.GetLinearVelocity()
         return (velocidad.x, velocidad.y)
@@ -239,15 +258,15 @@ class Figura(object):
 
     def empujar(self, dx=None, dy=None):
         self.definir_velocidad_lineal(dx, dy)
-        
+
     def eliminar(self):
         """Quita una figura de la simulación."""
         pilas.mundo.fisica.eliminar_figura(self._cuerpo)
-        
+
     x = property(obtener_x, definir_x, doc="define la posición horizontal.")
     y = property(obtener_y, definir_y, doc="define la posición vertical.")
     rotacion = property(obtener_rotacion, definir_rotacion, doc="define la rotacion.")
-    
+
 class Circulo(Figura):
     """Representa un cuerpo de circulo.
 
@@ -265,20 +284,26 @@ class Circulo(Figura):
         >>> mono.imitar(circulo_dinamico)
     """
 
-    def __init__(self, x, y, radio, dinamica=True, densidad=1.0, 
-            restitucion=0.56, friccion=10.5, amortiguacion=0.1, 
-            fisica=None):
+    def __init__(self, x, y, radio, dinamica=True, densidad=1.0,
+            restitucion=0.56, friccion=10.5, amortiguacion=0.1,
+            fisica=None, sin_rotacion=False):
+
+        Figura.__init__(self)
 
         if not fisica:
             fisica = pilas.mundo.fisica
-            
+
         bodyDef = box2d.b2BodyDef()
         bodyDef.position=(x, y)
         bodyDef.linearDamping = amortiguacion
+        bodyDef.fixedRotation = sin_rotacion
+
+        userData = { 'id' : self.id }
+
         #userData = { 'color' : self.parent.get_color() }
         #bodyDef.userData = userData
         #self.parent.element_count += 1
-        
+
         body = fisica.crear_cuerpo(bodyDef)
 
         # Create the Body
@@ -291,9 +316,10 @@ class Circulo(Figura):
         circleDef.radius = radio
         circleDef.restitution = restitucion
         circleDef.friction = friccion
-        
+        circleDef.userData = userData
+
         body.CreateShape(circleDef)
-        body.SetMassFromShapes()    
+        body.SetMassFromShapes()
 
         self._cuerpo = body
 
@@ -308,9 +334,11 @@ class Rectangulo(Figura):
         >>> actor.imitar(rect)
     """
 
-    def __init__(self, x, y, ancho, alto, dinamica=True, densidad=1.0, 
-            restitucion=0.56, friccion=10.5, amortiguacion=0.1, 
-            fisica=None):
+    def __init__(self, x, y, ancho, alto, dinamica=True, densidad=1.0,
+            restitucion=0.56, friccion=10.5, amortiguacion=0.1,
+            fisica=None, sin_rotacion=False):
+
+        Figura.__init__(self)
 
         if not fisica:
             fisica = pilas.mundo.fisica
@@ -318,11 +346,14 @@ class Rectangulo(Figura):
         bodyDef = box2d.b2BodyDef()
         bodyDef.position=(x, y)
         bodyDef.linearDamping = amortiguacion
-        
+        bodyDef.fixedRotation = sin_rotacion
+
+        userData = { 'id' : self.id }
+        #bodyDef.userData = userData
         #userData = { 'color' : self.parent.get_color() }
         #bodyDef.userData = userData
         #self.parent.element_count += 1
-        
+
         body = fisica.crear_cuerpo(bodyDef)
 
         # Create the Body
@@ -331,14 +362,15 @@ class Rectangulo(Figura):
 
         # Add a shape to the Body
         boxDef = box2d.b2PolygonDef()
-        
+
         boxDef.SetAsBox(ancho/2, alto/2, (0,0), 0)
         boxDef.density = densidad
         boxDef.restitution = restitucion
         boxDef.friction = friccion
+        boxDef.userData = userData
         body.CreateShape(boxDef)
 
-        body.SetMassFromShapes()    
+        body.SetMassFromShapes()
 
         self._cuerpo = body
 
@@ -353,21 +385,27 @@ class Poligono(Figura):
     Por ejemplo:
 
         >>> pilas.fisica.Poligono([(100, 2), (-50, 0), (-100, 100.0)])
-        
+
     """
-    
-    def __init__(self, puntos, dinamica=True, densidad=1.0, 
-            restitucion=0.56, friccion=10.5, amortiguacion=0.1, 
-            fisica=None):
+
+    def __init__(self, puntos, dinamica=True, densidad=1.0,
+            restitucion=0.56, friccion=10.5, amortiguacion=0.1,
+            fisica=None, sin_rotacion=False):
+
+        Figura.__init__(self)
 
         if not fisica:
             fisica = pilas.mundo.fisica
-            
+
         bodyDef = box2d.b2BodyDef()
         bodyDef.position=puntos[0]
         bodyDef.linearDamping = amortiguacion
+        bodyDef.fixedRotation = sin_rotacion
+        
         body = fisica.crear_cuerpo(bodyDef)
 
+        userData = { 'id' : self.id }
+        #bodyDef.userData = userData
         # Create the Body
         if not dinamica:
             densidad = 0
@@ -383,13 +421,15 @@ class Poligono(Figura):
         poligono_def.density = densidad
         poligono_def.restitution = restitucion
         poligono_def.friction = friccion
+
+        poligono_def.userData = userData
         #poligono_def.setVertices(puntos)
         #poligono_def.vertexCount = len(puntos)
 
         #for indice, punto in enumerate(puntos):
         #    poligono_def.setVertex(indice, punto[0], punto[1])
         #    #poligono_def.vertices[indice] = punto
-        
+
         body.CreateShape(poligono_def)
         body.SetMassFromShapes()
         self._cuerpo = body
@@ -432,21 +472,40 @@ class ConstanteDeDistancia():
     las figuras en el momento en que se establece la constante.
     """
 
-    def __init__(self, figura_1, figura_2, fisica=None):
+    def __init__(self, figura_1, figura_2, fisica=None, con_colision=True):
         if not fisica:
             fisica = pilas.mundo.fisica
-            
+
         if not isinstance(figura_1, Figura) or not isinstance(figura_2, Figura):
             raise Exception("Las dos figuras tienen que ser objetos de la clase Figura.")
-        
+
         constante = box2d.b2DistanceJointDef()
         constante.Initialize(figura_1._cuerpo, figura_2._cuerpo, (0,0), (0,0))
-        constante.collideConnected = True
+        constante.collideConnected = con_colision
         self.constante = fisica.mundo.CreateJoint(constante)
 
-
     def eliminar(self):
         pilas.mundo.fisica.mundo.DestroyJoint(self.constante_mouse)
 
 def definir_gravedad(x=0, y=-90):
     pilas.mundo.fisica.mundo.gravity = (x, y)
+
+class ObjetosContactListener(contact_listener):
+
+    def __init__(self):
+        box2d.b2ContactListener.__init__(self)
+
+    def Add(self, objetos_colisionados):
+        if (not (objetos_colisionados.shape1.GetUserData() == None)) and (not (objetos_colisionados.shape2.GetUserData() == None)):
+            pilas.mundo.colisiones.verificar_colisiones_fisicas(objetos_colisionados.shape1.GetUserData()['id'], objetos_colisionados.shape2.GetUserData()['id'])
+
+    def Persist(self, *args):
+        pass
+
+
+    def Remove(self, *args):
+        pass
+
+
+    def Result(self, *args):
+        pass
