@@ -11,6 +11,7 @@ import sys
 import copy
 from PyQt4 import QtGui, QtCore
 from PyQt4.QtGui import QWidget
+from PyQt4.QtGui import QMainWindow
 from PyQt4.phonon import Phonon
 
 try:
@@ -34,12 +35,12 @@ from pilas import colores
 import motor
 
 # Permite cerrar el programa usando CTRL+C
-import signal                                                                                    
+import signal
 signal.signal(signal.SIGINT, signal.SIG_DFL)
 
 
 class BaseActor(object):
-    
+
     def __init__(self):
         self._rotacion = 0
         self._transparencia = 0
@@ -84,10 +85,10 @@ class BaseActor(object):
 
     def definir_rotacion(self, r):
         self._rotacion = r
-        
-    def set_espejado(self, espejado):        
+
+    def set_espejado(self, espejado):
         self._espejado = espejado
-        
+
 class Imagen(object):
 
     def __init__(self, ruta):
@@ -162,7 +163,7 @@ class Grilla(Imagen):
         return self.cuadro_alto
 
     def _dibujar_pixmap(self, motor, x, y):
-        motor.canvas.drawPixmap(x, y, self._imagen, self.dx, self.dy, 
+        motor.canvas.drawPixmap(x, y, self._imagen, self.dx, self.dy,
                 self.cuadro_ancho, self.cuadro_alto)
 
     def definir_cuadro(self, cuadro):
@@ -423,55 +424,32 @@ class Actor(BaseActor):
                 self.centro_x, self.centro_y,
                 escala_x, escala_y, self._rotacion, self._transparencia)
 
-class _deprecated__Sonido:
-
-    def __init__(self, ruta):
-        import pygame
-        pygame.mixer.init()
-        self.sonido = pygame.mixer.Sound(ruta)
-
-    def reproducir(self):
-        self.sonido.play()
 
 class Sonido:
+    deshabilitado = False
 
     def __init__(self, media, ruta):
         self.media = media
         self.ruta = ruta
 
-        #if self.source.type() != -1:              # -1 stands for invalid file
-        #    self.media.setCurrentSource(self.source)
-        #    #app.connect(media, SIGNAL("finished()"), app, SLOT("quit()"))
-        #else:
-        #    print "error !!!"
         self.source = Phonon.MediaSource(ruta)
         self.sonido = Phonon.createPlayer(Phonon.GameCategory, self.source)
-        print "Creando sonido para", ruta
 
     def reproducir(self):
-        #self.source = Phonon.MediaSource(self.ruta)
-        #self.media.setCurrentSource(self.source)
-        #self.media.play()
-        #self.sonido.setCurrentSource(self.source)
-        self.sonido.seek(0)
-        self.sonido.play()
+        if not self.deshabilitado:
+            self.sonido.seek(0)
+            self.sonido.play()
 
-class Musica:
+    def detener(self):
+        self.sonido.stop()
 
-    def __init__(self, ruta):
-        import pygame
-        pygame.mixer.init()
-        pygame.mixer.music.load(ruta)
+class Musica(Sonido):
 
-    def reproducir(self, repetir=False):
-        import pygame
-        if repetir:
-            pygame.mixer.music.play(-1)
-        else:
-            pygame.mixer.music.play(0)
+    def __init__(self, media, ruta):
+        Sonido.__init__(self, media, ruta)
 
 class Base(motor.Motor):
-    
+
     def __init__(self):
         motor.Motor.__init__(self)
         self.canvas = QtGui.QPainter()
@@ -483,10 +461,12 @@ class Base(motor.Motor):
         self.mouse_y = 0
         self.camara_x = 0
         self.camara_y = 0
-    
+
         self.media = Phonon.MediaObject()
         self.audio = Phonon.AudioOutput(Phonon.MusicCategory)
         self.path = Phonon.createPath(self.media, self.audio)
+        
+        self._widgetlog = None
 
     def iniciar_ventana(self, ancho, alto, titulo, pantalla_completa):
         self.ancho = ancho
@@ -508,6 +488,8 @@ class Base(motor.Motor):
         else:
             self.show()
 
+        self.raise_()
+
     def pantalla_completa(self):
         self.showFullScreen()
 
@@ -537,12 +519,23 @@ class Base(motor.Motor):
     def centrar_ventana(self):
         escritorio = QtGui.QDesktopWidget().screenGeometry()
         self.setGeometry(
-                    (escritorio.width()-self.ancho)/2, 
+                    (escritorio.width()-self.ancho)/2,
                     (escritorio.height()-self.alto)/2, self.ancho, self.alto)
 
     def obtener_actor(self, imagen, x, y):
         return Actor(imagen, x, y)
 
+    def actor_en_pantalla(self, actor):
+        """ Confirma si un actor se encuentra dentro de la pantalla """
+        if (actor.x + (actor.ancho - actor.obtener_centro()[0]) >= (self.camara_x - (self.ancho_original/2)) and
+            actor.y + (actor.alto - actor.obtener_centro()[1]) >= (self.camara_y - (self.alto_original/2)) and
+            actor.x - (actor.ancho - actor.obtener_centro()[0]) <= (self.camara_x + (self.ancho_original/2)) and
+            actor.y - (actor.alto - actor.obtener_centro()[1]) <= (self.camara_y + (self.alto_original/2))):            
+            return True        
+        else:
+            return False
+         
+    
     def obtener_texto(self, texto, magnitud):
         return Texto(texto, magnitud, self)
 
@@ -563,7 +556,13 @@ class Base(motor.Motor):
         return Sonido(self.media, ruta)
 
     def cargar_musica(self, ruta):
-        return Musica(ruta)
+        return Musica(self.media, ruta)
+
+    def deshabilitar_sonido(self, estado=True):
+        Sonido.deshabilitado = estado
+
+    def deshabilitar_musica(self, estado=True):
+        Musica.deshabilitado = estado
 
     def cargar_imagen(self, ruta):
         return Imagen(ruta)
@@ -595,7 +594,9 @@ class Base(motor.Motor):
 
         for actor in actores.todos:
             try:
-                actor.dibujar(self)
+                # Si el actor se encuantra dentro del area visible se dibuja.
+                if self.actor_en_pantalla(actor):
+                    actor.dibujar(self)
             except Exception as e:
                 print e
                 actor.eliminar()
@@ -618,14 +619,15 @@ class Base(motor.Motor):
     def realizar_actualizacion_logica(self):
         for x in range(self.fps.actualizar()):
             if not self.pausa_habilitada:
-                eventos.actualizar.send("Qt::timerEvent")
+                self._actualizar_eventos_y_actores()
 
-                for actor in actores.todos:
-                    actor.pre_actualizar()
-                    actor.actualizar()
-            else:
-                eventos.actualizar_pausado.send("Qt::timerEvent")
 
+    def _actualizar_eventos_y_actores(self):
+        eventos.actualizar.emitir()
+
+        for actor in actores.todos:
+            actor.pre_actualizar()
+            actor.actualizar()
 
     def resizeEvent(self, event):
         self.ancho = event.size().width()
@@ -634,26 +636,26 @@ class Base(motor.Motor):
     def mousePressEvent(self, e):
         escala = self.escala()
         x, y = utils.convertir_de_posicion_fisica_relativa(e.pos().x()/escala, e.pos().y()/escala)
-        eventos.click_de_mouse.send("Qt::mousePressEvent", x=x, y=y, dx=0, dy=0)
+        eventos.click_de_mouse.emitir(x=x, y=y, dx=0, dy=0)
 
     def mouseReleaseEvent(self, e):
         escala = self.escala()
         x, y = utils.convertir_de_posicion_fisica_relativa(e.pos().x()/escala, e.pos().y()/escala)
-        eventos.termina_click.send("Qt::mouseReleaseEvent", x=x, y=y, dx=0, dy=0)
+        eventos.termina_click.emitir(x=x, y=y, dx=0, dy=0)
 
     def wheelEvent(self, e):
-        eventos.mueve_rueda.send("ejecutar", delta=e.delta() / 120)
+        eventos.mueve_rueda.emitir(delta=e.delta() / 120)
 
     def mouseMoveEvent(self, e):
         escala = self.escala()
         x, y = utils.convertir_de_posicion_fisica_relativa(e.pos().x()/escala, e.pos().y()/escala)
         dx, dy = x - self.mouse_x, y - self.mouse_y
-        
+
         izquierda, derecha, arriba, abajo = utils.obtener_bordes()
         x = max(min(derecha, x), izquierda)
         y = max(min(arriba, y), abajo)
 
-        eventos.mueve_mouse.send("Qt::mouseMoveEvent", x=x, y=y, dx=dx, dy=dy)
+        eventos.mueve_mouse.emitir(x=x, y=y, dx=dx, dy=dy)
         self.mouse_x = x
         self.mouse_y = y
 
@@ -661,17 +663,18 @@ class Base(motor.Motor):
         codigo_de_tecla = self.obtener_codigo_de_tecla_normalizado(event.key())
 
         if event.key() == QtCore.Qt.Key_Escape:
-            eventos.pulsa_tecla_escape.send("Qt::keyPressEvent")
+            eventos.pulsa_tecla_escape.emitir()
         if event.key() == QtCore.Qt.Key_P and event.modifiers() == QtCore.Qt.AltModifier:
             self.alternar_pausa()
         if event.key() == QtCore.Qt.Key_F and event.modifiers() == QtCore.Qt.AltModifier:
             self.alternar_pantalla_completa()
 
-        eventos.pulsa_tecla.send("Qt::keyPressEvent", codigo=codigo_de_tecla, texto=event.text())
+        eventos.pulsa_tecla.emitir(codigo=codigo_de_tecla, es_repeticion=event.isAutoRepeat(), texto=event.text())
+
 
     def keyReleaseEvent(self, event):
         codigo_de_tecla = self.obtener_codigo_de_tecla_normalizado(event.key())
-        eventos.suelta_tecla.send("Qt::keyReleaseEvent", codigo=codigo_de_tecla, texto=event.text())
+        eventos.suelta_tecla.emitir(codigo=codigo_de_tecla, es_repeticion=event.isAutoRepeat(), texto=event.text())
 
     def obtener_codigo_de_tecla_normalizado(self, tecla_qt):
         teclas = {
@@ -750,9 +753,15 @@ class Base(motor.Motor):
         if self.pausa_habilitada:
             self.pausa_habilitada = False
             self.actor_pausa.eliminar()
+            eventos.pulsa_tecla.desconectar_por_id('tecla_en_pausa')
         else:
             self.pausa_habilitada = True
             self.actor_pausa = actores.Pausa()
+            self.actor_pausa.fijo = True
+            self.id_evento = eventos.pulsa_tecla.conectar(self.avanzar_un_solo_cuadro_de_animacion, id='tecla_en_pausa')
+
+    def avanzar_un_solo_cuadro_de_animacion(self, evento):
+        self._actualizar_eventos_y_actores()
 
     def ocultar_puntero_del_mouse(self):
         bitmap = QtGui.QBitmap(1, 1)
@@ -762,12 +771,20 @@ class Base(motor.Motor):
     def terminar(self):
         self.close()
 
+    def log(self, params):
+        if (self._widgetlog == None):
+            self._widgetlog = WidgetLog()
+        else:
+            self._widgetlog.show()
+        
+        self._widgetlog.imprimir(params)
+
 class Widget(Base, QWidget):
 
     def __init__(self, app):
         self.nombre = 'qt (cuidado: sin acelerar)'
         self.app = app
-        QWidget.__init__(self)
+        QWidget.__init__(self, None, QtCore.Qt.WindowStaysOnTopHint)
         Base.__init__(self)
 
 
@@ -781,13 +798,13 @@ class WidgetGL(Base, QGLWidget):
         if not QGLWidget:
             print "Lo siento, OpenGL no esta disponible..."
 
-        QGLWidget.__init__(self)
+        QGLWidget.__init__(self, None, None, QtCore.Qt.WindowStaysOnTopHint)
         Base.__init__(self)
         self._pintar_fondo_negro()
 
     def _pintar_fondo_negro(self):
         color = QtGui.QColor(99, 0, 0)
-        self.setStyleSheet("QWidget { background-color: %s }" % color.name())
+        self.setStyleSheet("QFrame { background-color: %s }" % color.name())
 
 class WidgetSugar(Widget):
 
@@ -813,13 +830,147 @@ class WidgetSugarGL(WidgetGL):
     def mostrar_ventana(self, pantalla_completa):
         pass
 
+class WidgetLog(QMainWindow):
+    """ Representa una ventana de log.    
+    Mediante pilas.log.imprimir() añadiremos elementos a esta ventana
+    """
+    def __init__(self):
+        super(WidgetLog, self).__init__()
+        self._initUI()
+        
+        self._ejecutando = True 
+        
+    def _initUI(self):
+        
+        self.setWindowTitle('Pilas Log')
+
+        self.setWindowIcon(QtGui.QIcon(self._ruta_icono('tux.png')))
+        
+        self.centralwidget = QtGui.QWidget(self)
+        
+        accionSalir = QtGui.QAction(QtGui.QIcon(self._ruta_icono('door_out.png')), 'Salir', self)
+        accionSalir.setShortcut('Ctrl+S')
+        accionSalir.triggered.connect(self.close)
+
+        accionEjecutar = QtGui.QAction(QtGui.QIcon(self._ruta_icono('control_play.png')), 'Ejecutar', self)
+        accionEjecutar.setShortcut('Ctrl+E')
+        accionEjecutar.triggered.connect(self._ejecutar)
+
+        accionPausar = QtGui.QAction(QtGui.QIcon(self._ruta_icono('control_pause.png')), 'Pausar', self)
+        accionPausar.setShortcut('Ctrl+P')
+        accionPausar.triggered.connect(self._pausar)
+
+        accionResetear = QtGui.QAction(QtGui.QIcon(self._ruta_icono('arrow_refresh.png')), 'Resetear', self)
+        accionResetear.setShortcut('Ctrl+R')
+        accionResetear.triggered.connect(self._resetear)
+
+        self.toolbar = self.addToolBar('Acciones')
+        self.toolbar.addAction(accionSalir) 
+        self.toolbar.addAction(accionEjecutar)
+        self.toolbar.addAction(accionPausar)
+        self.toolbar.addAction(accionResetear)
+               
+        hbox = QtGui.QHBoxLayout(self.centralwidget)
+
+        self.treeView = QtGui.QTreeWidget(self.centralwidget)
+        
+        self.treeView.setColumnCount(2)
+        
+        cabecera = QtCore.QStringList()
+        cabecera.append("Clave")
+        cabecera.append("Valor")
+        
+        self.treeView.setHeaderLabels(cabecera)              
+                
+        hbox.addWidget(self.treeView)
+        
+        self.setCentralWidget(self.centralwidget)  
+
+        self._ejecutar()
+        
+        self.setGeometry(50, 50, 250, 250)
+        self.show()
+        
+    def _ejecutar(self):
+        self._ejecutando = True
+        self.statusBar().showMessage('Ejecutando')
+        
+    def _pausar(self):
+        self._ejecutando = False
+        self.statusBar().showMessage('Pausado')
+        
+    def _resetear(self):
+        self.treeView.clear()
+        self._ejecutar()
+            
+    def _ruta_icono(self, icono):
+        return os.path.join('..', '..', '..', 'data' , 'iconos', icono)
+    
+    def imprimir(self, params):
+        if (self._ejecutando):
+            for elemento in params:
+                self._insertar_elemento(elemento)
+            
+            self.treeView.header().setResizeMode(3)                         
+    
+    def _insertar_elemento(self, elemento, elemento_padre=None):
+        
+        if (self._contiene_diccionario(elemento)):
+            if (hasattr(elemento, '__class__')):
+                if (elemento.__class__.__name__ != 'dict'):
+                    padre = self._insertar_texto_en_lista(elemento.__class__.__name__, elemento_padre)
+                else:
+                    padre = None
+            else:
+                padre = None
+                
+            for key, value in self._obtener_diccionario(elemento):
+                if self._contiene_diccionario(value):                    
+                    self._insertar_elemento(value, self._insertar_texto_en_lista(key, padre))
+                else:
+                    self._insertar_diccionario_en_lista(key, value, padre)
+        else:
+            self._insertar_texto_en_lista(str(elemento))                
+        
+        
+    def _contiene_diccionario(self, valor):
+        if hasattr(valor, '__dict__'):
+            return True
+        elif type(valor) is dict:
+            return True
+        else:
+            return False 
+
+    def _obtener_diccionario(self, valor):
+        if hasattr(valor, '__dict__'):
+            return valor.__dict__.items()
+        elif type(valor) is dict:
+            return valor.items()
+    
+    def _insertar_texto_en_lista(self, texto, itemPadre=None):
+        if (itemPadre == None):
+            item = QtGui.QTreeWidgetItem(self.treeView)
+        else:
+            item = QtGui.QTreeWidgetItem(itemPadre)
+        item.setText(0, str(texto))
+        return item
+            
+    def _insertar_diccionario_en_lista(self, clave, valor, itemPadre=None):
+        if (itemPadre == None):
+            item = QtGui.QTreeWidgetItem(self.treeView)
+        else:
+            item = QtGui.QTreeWidgetItem(itemPadre)
+        item.setText(0, clave)
+        item.setText(1, str(valor))
+        return item
+    
 class Motor(object):
     """Representa la ventana principal de pilas.
-    
+
     Esta clase construirá el objeto apuntado por el atributo
     ``pilas.motor``, asi que será el representante de todas
     las funcionalidades multimedia.
-    
+
     Internamente, este motor, tratará de usar OpenGl para acelerar
     el dibujado en pantalla si la tarjeta de video lo soporta.
     """
@@ -842,6 +993,9 @@ class Motor(object):
         elif usar_motor == 'qtsugargl':
             self.widget = WidgetSugarGL()
 
+        self.widgetlog = None
+        
+        
     def __getattr__(self, method):
         "Delega todos los pedidos de funcionalidad al widget interno."
         return getattr(self.widget, method)
